"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CommentReplyNode = exports.CommentContentNode = exports.CommentFileNode = exports.CommentRoot = void 0;
const ide_components_1 = require("@opensumi/ide-components");
class CommentRoot extends ide_components_1.CompositeTreeNode {
    static is(node) {
        return !!node && !node.parent;
    }
    constructor(tree) {
        super(tree, undefined);
    }
    get expanded() {
        return true;
    }
}
exports.CommentRoot = CommentRoot;
class CommentFileNode extends ide_components_1.CompositeTreeNode {
    static is(node) {
        return ide_components_1.CompositeTreeNode.is(node) && 'threads' in node;
    }
    constructor(tree, threads, description = '', tooltip, icon, resource, parent) {
        super(tree, parent);
        this.threads = threads;
        this.tooltip = tooltip;
        this.icon = icon;
        this.resource = resource;
        this.isExpanded = true;
        this._renderedLabel = this.resource.displayName;
        this._renderedDescription = description;
    }
    set label(value) {
        this._renderedLabel = value;
    }
    set description(value) {
        this._renderedDescription = value;
    }
    get renderedLabel() {
        return this._renderedLabel;
    }
    get renderedDescription() {
        return this._renderedDescription;
    }
    set onSelect(handler) {
        this._onSelectHandler = handler;
    }
    get onSelect() {
        return this._onSelectHandler;
    }
}
exports.CommentFileNode = CommentFileNode;
class CommentContentNode extends ide_components_1.CompositeTreeNode {
    static is(node) {
        return ide_components_1.CompositeTreeNode.is(node) && 'author' in node;
    }
    constructor(tree, thread, comment, description = '', icon, author, resource, parent) {
        super(tree, parent);
        this.thread = thread;
        this.comment = comment;
        this.icon = icon;
        this.author = author;
        this.resource = resource;
        this._renderedDescription = description;
        // 评论节点默认是展开状态
        this.isExpanded = true;
        // 是否允许通过 toggleExpand 来展开收起，可以由上层控制，默认不允许
        this._isAllowToggle = false;
    }
    get isAllowToggle() {
        return this._isAllowToggle;
    }
    setIsAllowToggle(v) {
        this._isAllowToggle = v;
    }
    set label(value) {
        this._renderedLabel = value;
    }
    set description(value) {
        this._renderedDescription = value;
    }
    get renderedLabel() {
        return this._renderedLabel;
    }
    get renderedDescription() {
        return this._renderedDescription;
    }
    set onSelect(handler) {
        this._onSelectHandler = handler;
    }
    get onSelect() {
        return this._onSelectHandler;
    }
}
exports.CommentContentNode = CommentContentNode;
class CommentReplyNode extends ide_components_1.TreeNode {
    constructor(tree, thread, label, description = '', icon, resource, parent) {
        super(tree, parent);
        this.thread = thread;
        this.icon = icon;
        this.resource = resource;
        this._renderedLabel = label;
        this._renderedDescription = description;
    }
    set label(value) {
        this._renderedLabel = value;
    }
    set description(value) {
        this._renderedDescription = value;
    }
    get renderedLabel() {
        return this._renderedLabel;
    }
    get renderedDescription() {
        return this._renderedDescription;
    }
    set onSelect(handler) {
        this._onSelectHandler = handler;
    }
    get onSelect() {
        return this._onSelectHandler;
    }
}
exports.CommentReplyNode = CommentReplyNode;
//# sourceMappingURL=tree-node.defined.js.map